==> qtjambi-quick-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiQuick/QSGD3D11Texture_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtQuick/qsgtexture_platform.h>)
#include <QtQuick/qsgtexture_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtCore/qsize.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgtexture.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if defined(Q_OS_WIN)



#endif // defined(Q_OS_WIN)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QSGD3D11Texture::nativeTexture()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGD3D11Texture_00024Impl_00024ConcreteWrapper_nativeTexture_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        const QNativeInterface::QSGD3D11Texture *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QSGD3D11Texture>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QSGD3D11Texture::nativeTexture()const", __this_nativeId)
        void* __qt_return_value = __qt_this->nativeTexture();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1, 1);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGD3D11Texture::fromNative(void*,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGD3D11Texture_00024Impl_fromNative_1native_1void_1ptr_1QQuickWindow_1ptr_1cref_1QSize_1QQuickWindow_1CreateTextureOptions__Lio_qt_QNativePointer_2JJI)
(JNIEnv *__jni_env,
 jclass,
 jobject texture0,
 QtJambiNativeID window1,
 QtJambiNativeID size2,
 jint options3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QSGD3D11Texture::fromNative(void*,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        void* __qt_texture0 = reinterpret_cast<void*>(QtJambiAPI::convertQNativePointerToNative(__jni_env, texture0));
        QQuickWindow* __qt_window1 = QtJambiAPI::objectFromNativeId<QQuickWindow>(window1);
        const QSize& __qt_size2 = QtJambiAPI::valueReferenceFromNativeId<QSize>(size2);
        QQuickWindow::CreateTextureOptions __qt_options3 = qtjambi_cast<QQuickWindow::CreateTextureOptions>(__jni_env, options3);
        QSGTexture* __qt_return_value = QNativeInterface::QSGD3D11Texture::fromNative(__qt_texture0, __qt_window1, __qt_size2, QQuickWindow::CreateTextureOptions(__qt_options3));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(texture0)
        Q_UNUSED(window1)
        Q_UNUSED(size2)
        Q_UNUSED(options3)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QSGD3D11Texture(){
    using namespace RegistryAPI;

#if defined(Q_OS_WIN)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QSGD3D11Texture>("QNativeInterface::QSGD3D11Texture", "io/qt/quick/nativeinterface/QSGD3D11Texture");
    registerNativeInterface<QNativeInterface::QSGD3D11Texture>("io/qt/quick/nativeinterface/QSGD3D11Texture");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QSGD3D11Texture* _object = dynamic_cast<QNativeInterface::QSGD3D11Texture*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QSGD3D11Texture *object = reinterpret_cast<QNativeInterface::QSGD3D11Texture *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QSGD3D11Texture *object = reinterpret_cast<const QNativeInterface::QSGD3D11Texture *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //defined(Q_OS_WIN)

    registerNativeInterface("io/qt/quick/nativeinterface/QSGD3D11Texture", {});

#endif //defined(Q_OS_WIN)

}

==> qtjambi-quick-debuginfo-linux-x64-6.6.1.jar: sources/QtJambiQuick/QSGD3D11Texture_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtQuick/qsgtexture_platform.h>)
#include <QtQuick/qsgtexture_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtCore/qsize.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgtexture.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if defined(Q_OS_WIN)



#endif // defined(Q_OS_WIN)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QSGD3D11Texture::nativeTexture()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGD3D11Texture_00024Impl_00024ConcreteWrapper_nativeTexture_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        const QNativeInterface::QSGD3D11Texture *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QSGD3D11Texture>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QSGD3D11Texture::nativeTexture()const", __qt_this)
        void* __qt_return_value = __qt_this->nativeTexture();
        __java_return_value = QtJambiAPI::convertNativeToQNativePointer(__jni_env, __qt_return_value, QNativePointer::Type::Pointer, 1);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGD3D11Texture::fromNative(void*,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGD3D11Texture_00024Impl_fromNative_1native_1void_1ptr_1QQuickWindow_1ptr_1cref_1QSize_1QQuickWindow_1CreateTextureOptions__Lio_qt_QNativePointer_2JJI)
(JNIEnv *__jni_env,
 jclass,
 jobject texture0,
 QtJambiNativeID window1,
 QtJambiNativeID size2,
 jint options3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QSGD3D11Texture::fromNative(void*,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if defined(Q_OS_WIN)
        void* __qt_texture0 = reinterpret_cast<void* >(QtJambiAPI::convertQNativePointerToNative(__jni_env, texture0, 1));
        QQuickWindow* __qt_window1 = QtJambiAPI::objectFromNativeId<QQuickWindow>(window1);
        const QSize& __qt_size2 = QtJambiAPI::valueReferenceFromNativeId<QSize>(size2);
        QQuickWindow::CreateTextureOptions __qt_options3 = qtjambi_cast<QQuickWindow::CreateTextureOptions>(__jni_env, options3);
        QSGTexture* __qt_return_value = QNativeInterface::QSGD3D11Texture::fromNative(__qt_texture0, __qt_window1, __qt_size2, QQuickWindow::CreateTextureOptions(__qt_options3));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(texture0)
        Q_UNUSED(window1)
        Q_UNUSED(size2)
        Q_UNUSED(options3)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // defined(Q_OS_WIN)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QSGD3D11Texture(){
    using namespace RegistryAPI;

#if defined(Q_OS_WIN)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QSGD3D11Texture>("QNativeInterface::QSGD3D11Texture", "io/qt/quick/nativeinterface/QSGD3D11Texture");
    registerNativeInterface<QNativeInterface::QSGD3D11Texture>("io/qt/quick/nativeinterface/QSGD3D11Texture");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QSGD3D11Texture* _object = dynamic_cast<QNativeInterface::QSGD3D11Texture*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QSGD3D11Texture *object = reinterpret_cast<QNativeInterface::QSGD3D11Texture *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QSGD3D11Texture *object = reinterpret_cast<const QNativeInterface::QSGD3D11Texture *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //defined(Q_OS_WIN)

    registerNativeInterface("io/qt/quick/nativeinterface/QSGD3D11Texture", {});

#endif //defined(Q_OS_WIN)

}
